@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000013';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000014';
 use Moose;
 use namespace::autoclean;
 
@@ -11,6 +11,7 @@ use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::ConfirmRelease;
 use Dist::Zilla::Plugin::ContributorsFile;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
+use Dist::Zilla::Plugin::CopyFilesFromRelease;
 use Dist::Zilla::Plugin::ExecDir;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::Git::Commit;
@@ -78,13 +79,14 @@ has stopwords_file => (
 sub configure {
     my $self = shift;
 
-    my $readme = 'README.md';
-    my @copy   = (
-        'cpanfile', 'Install', 'LICENSE', 'Makefile.PL', 'META.json',
-        $readme
+    my $readme          = 'README.md';
+    my @copy_from_build = (
+        'cpanfile', 'LICENSE', 'Makefile.PL', 'META.json', $readme,
     );
+    my @copy_from_release = ('Install');
 
-    my @allow_dirty = ( 'dist.ini', 'Changes', @copy );
+    my @allow_dirty
+        = ( 'dist.ini', 'Changes', @copy_from_build, @copy_from_release );
 
     my @plugins = (
         [
@@ -101,21 +103,44 @@ sub configure {
             }
         ],
 
+        'MAXMIND::TidyAll',
+
         'AutoPrereqs',
         'CheckChangesHasContent',
-        'ConfirmRelease',
         'MakeMaker',    # needs to precede InstallGuide
         'CPANFile',
         'ContributorsFile',
-        'InstallGuide',
         'MetaJSON',
         'MetaYAML',
+        'Manifest',
+        'ManifestSkip',
+        [ 'MetaNoIndex' => { directory => [ 'examples', 't', 'xt' ] } ],
+        'MetaConfig',
+        'MetaResources',
         'License',
-        [ 'CopyFilesFromBuild' => { copy => \@copy } ],
+        'InstallGuide',
+
+        'Prereqs',
+
         'ExecDir',
 
+        [ 'Test::PodSpelling' => { stopwords => $self->_all_stopwords } ],
+        'PodCoverageTests',
+        'Test::CPAN::Changes',
+        'TestRelease',
+        'Test::ReportPrereqs',
+        'Test::Synopsis',
+        'Test::TidyAll',
+
         'RunExtraTests',
 
+        'MinimumPerl',
+        'PkgVersion',
+        'PodWeaver',
+        'PruneCruft',
+
+        [ 'CopyFilesFromBuild' => { copy => \@copy_from_build } ],
+
         [
             'NextRelease' => {
                 time_zone => 'UTC',
@@ -125,8 +150,9 @@ sub configure {
         ],
 
         [ 'GithubMeta'     => { issues           => 1 } ],
-        [ 'Git::GatherDir' => { exclude_filename => \@copy } ],
-        [ 'Git::Check'     => { allow_dirty      => \@allow_dirty } ],
+        [ 'Git::GatherDir' => { exclude_filename => \@copy_from_build } ],
+        [ 'CopyFilesFromRelease' => { filename    => [@copy_from_release] } ],
+        [ 'Git::Check'           => { allow_dirty => \@allow_dirty } ],
         [
             'Git::Commit' => 'commit generated files' => {
                 allow_dirty => \@allow_dirty,
@@ -135,18 +161,7 @@ sub configure {
         'Git::Contributors',
         'Git::Tag',
         'Git::Push',
-        'Manifest',
-        'ManifestSkip',
-        'MAXMIND::TidyAll',
-        [ 'MetaNoIndex' => { directory => [ 'examples', 't', 'xt' ] } ],
-        'MetaResources',
-        'MetaConfig',
-        'MinimumPerl',
-        'PkgVersion',
-        'PodCoverageTests',
-        'PodWeaver',
-        'Prereqs',
-        'PruneCruft',
+
         [
             'ReadmeAnyFromPod' => 'ReadmeMdInBuild' => {
                 filename => $readme,
@@ -155,13 +170,8 @@ sub configure {
             }
         ],
         'ShareDir',
-        'Test::CPAN::Changes',
-        [ 'Test::PodSpelling' => { stopwords => $self->_all_stopwords } ],
-        'TestRelease',
-        'Test::ReportPrereqs',
-        'Test::Synopsis',
-        'Test::TidyAll',
         'TravisCI::StatusBadge',
+        'ConfirmRelease',
         'UploadToCPAN',
     );
 
@@ -205,7 +215,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000013
+version 0.000014
 
 =head2 configure
 
